@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Test::Routine::Util;
 {
-  $Test::Routine::Util::VERSION = '0.014';
+  $Test::Routine::Util::VERSION = '0.016';
 }
 # ABSTRACT: helpful exports for dealing with test routines
 
@@ -39,7 +39,7 @@ sub run_me {
   my ($class, $desc, $arg) = @_;
 
   if (@_ == 2 and (reftype $desc || '') eq 'HASH') {
-    ($desc, $arg) = (undef, $arg);
+    ($desc, $arg) = (undef, $desc);
   }
 
   my $caller = caller($UPLEVEL);
@@ -73,15 +73,18 @@ sub run_tests {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Routine::Util - helpful exports for dealing with test routines
 
 =head1 VERSION
 
-version 0.014
+version 0.016
 
 =head1 OVERVIEW
 
@@ -105,4 +108,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
